==> chromium_113.0.5672.126.orig.tar.xz: chromium-113.0.5672.126/ash/wm/tablet_mode/tablet_mode_multitask_menu_event_handler.h <==
// Copyright 2022 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_WM_TABLET_MODE_TABLET_MODE_MULTITASK_MENU_EVENT_HANDLER_H_
#define ASH_WM_TABLET_MODE_TABLET_MODE_MULTITASK_MENU_EVENT_HANDLER_H_

#include "third_party/abseil-cpp/absl/types/optional.h"
#include "ui/aura/window_observer.h"
#include "ui/events/event_handler.h"
#include "ui/gfx/geometry/rect_f.h"

namespace ash {

class TabletModeMultitaskMenu;
class TabletModeMultitaskCue;

// TabletModeMultitaskMenuEventHandler handles gestures in tablet mode that may
// show or hide the multitask menu.
class TabletModeMultitaskMenuEventHandler : public ui::EventHandler {
 public:
  TabletModeMultitaskMenuEventHandler();
  TabletModeMultitaskMenuEventHandler(
      const TabletModeMultitaskMenuEventHandler&) = delete;
  TabletModeMultitaskMenuEventHandler& operator=(
      const TabletModeMultitaskMenuEventHandler&) = delete;
  ~TabletModeMultitaskMenuEventHandler() override;

  static bool CanShowMenu(aura::Window* window);

  TabletModeMultitaskMenu* multitask_menu() { return multitask_menu_.get(); }

  // Creates and shows the menu.
  void ShowMultitaskMenu(aura::Window* window);

  // Destroys the multitask menu.
  void ResetMultitaskMenu();

  // ui::EventHandler:
  void OnTouchEvent(ui::TouchEvent* event) override;

  TabletModeMultitaskCue* multitask_cue_for_testing() {
    return multitask_cue_.get();
  }

 private:
  // Drag data needed to process menu events. `initial_location` is the initial
  // touch in screen coordinates, and `is_drag` indicates whether this was
  // actually a drag, since the touch may have pressed and released immediately.
  struct InitialDragData {
    gfx::PointF initial_location;
    bool is_drag;
  };

  bool CanProcessEvent(aura::Window* window) const;

  void MaybeCreateMultitaskMenu(aura::Window* active_window);

  // Valid if we may need to handle the event.
  absl::optional<InitialDragData> initial_drag_data_;

  // Creates a draggable bar when app windows are activated.
  std::unique_ptr<TabletModeMultitaskCue> multitask_cue_;

  std::unique_ptr<TabletModeMultitaskMenu> multitask_menu_;
};

}  // namespace ash

#endif  // ASH_WM_TABLET_MODE_TABLET_MODE_MULTITASK_MENU_EVENT_HANDLER_H_

==> chromium_115.0.5790.98.orig.tar.xz: chromium-115.0.5790.98/ash/wm/tablet_mode/tablet_mode_multitask_menu_event_handler.h <==
// Copyright 2022 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_WM_TABLET_MODE_TABLET_MODE_MULTITASK_MENU_EVENT_HANDLER_H_
#define ASH_WM_TABLET_MODE_TABLET_MODE_MULTITASK_MENU_EVENT_HANDLER_H_

#include "third_party/abseil-cpp/absl/types/optional.h"
#include "ui/aura/window_observer.h"
#include "ui/events/event_handler.h"
#include "ui/gfx/geometry/rect_f.h"

namespace ash {

class TabletModeMultitaskMenu;
class TabletModeMultitaskCue;

// TabletModeMultitaskMenuEventHandler handles gestures in tablet mode that may
// show or hide the multitask menu.
class TabletModeMultitaskMenuEventHandler : public ui::EventHandler {
 public:
  TabletModeMultitaskMenuEventHandler();
  TabletModeMultitaskMenuEventHandler(
      const TabletModeMultitaskMenuEventHandler&) = delete;
  TabletModeMultitaskMenuEventHandler& operator=(
      const TabletModeMultitaskMenuEventHandler&) = delete;
  ~TabletModeMultitaskMenuEventHandler() override;

  static bool CanShowMenu(aura::Window* window);

  TabletModeMultitaskMenu* multitask_menu() { return multitask_menu_.get(); }
  TabletModeMultitaskCue* multitask_cue() { return multitask_cue_.get(); }

  // Creates and shows the menu.
  void ShowMultitaskMenu(aura::Window* window);

  // Destroys the multitask menu and resets the position of the cue if it is
  // visible.
  void ResetMultitaskMenu();

  // ui::EventHandler:
  void OnGestureEvent(ui::GestureEvent* event) override;

 private:
  void MaybeCreateMultitaskMenu(aura::Window* active_window);

  // True while a drag to open or close the menu is in progress. Needed since a
  // drag may go outside menu bounds, during which we still handle events.
  bool is_drag_active_ = false;

  // Creates a draggable bar when app windows are activated.
  std::unique_ptr<TabletModeMultitaskCue> multitask_cue_;

  std::unique_ptr<TabletModeMultitaskMenu> multitask_menu_;
};

}  // namespace ash

#endif  // ASH_WM_TABLET_MODE_TABLET_MODE_MULTITASK_MENU_EVENT_HANDLER_H_
